From a22a190cdac5a0257d7bff0c79d112e791ff35c8 Mon Sep 17 00:00:00 2001
From: Caroline Ruffel <caroline.ruffel@c-s.fr>
Date: Thu, 20 Apr 2006 09:29:02 +0000
Subject: [PATCH] nomsg

---
 Code/FeatureExtraction/otbTouziEdgeDetector.h | 24 +++++++++----------
 .../otbTouziEdgeDetector.txx                  | 20 ++++++++--------
 2 files changed, 22 insertions(+), 22 deletions(-)

diff --git a/Code/FeatureExtraction/otbTouziEdgeDetector.txx b/Code/FeatureExtraction/otbTouziEdgeDetector.txx
index fca4e60e19..2b7d4760ce 100755
--- a/Code/FeatureExtraction/otbTouziEdgeDetector.txx
+++ b/Code/FeatureExtraction/otbTouziEdgeDetector.txx
@@ -8,10 +8,10 @@
   $Id$ 
 
 =========================================================================*/
-#ifndef __otbTouziEdgeDetector_txx
-#define __otbTouziEdgeDetector_txx
+#ifndef __otbTouziEdgeDetectorImageFilter_txx
+#define __otbTouziEdgeDetectorImageFilter_txx
 
-#include "otbTouziEdgeDetector.h"
+#include "otbTouziEdgeDetectorImageFilter.h"
 
 #include "itkDataObject.h"
 #include "itkExceptionObject.h"
@@ -33,13 +33,13 @@ namespace otb
  *
  */
 template <class TInputImage, class TOutputImage>
-TouziEdgeDetector<TInputImage, TOutputImage>::TouziEdgeDetector()
+TouziEdgeDetectorImageFilter<TInputImage, TOutputImage>::TouziEdgeDetectorImageFilter()
 {
   m_Radius.Fill(1);
 }
 
 template <class TInputImage, class TOutputImage>
-void TouziEdgeDetector<TInputImage, TOutputImage>::GenerateInputRequestedRegion() throw (itk::InvalidRequestedRegionError)
+void TouziEdgeDetectorImageFilter<TInputImage, TOutputImage>::GenerateInputRequestedRegion() throw (itk::InvalidRequestedRegionError)
 {
   // call the superclass' implementation of this method
   Superclass::GenerateInputRequestedRegion();
@@ -94,7 +94,7 @@ void TouziEdgeDetector<TInputImage, TOutputImage>::GenerateInputRequestedRegion(
  */
 template <class TInputImage, class TOutputImage>
 void 
-TouziEdgeDetector<TInputImage,TOutputImage>
+TouziEdgeDetectorImageFilter<TInputImage,TOutputImage>
 ::BeforeThreadedGenerateData()
 {
 //  std::cout << " BeforeThreadedGenerateData"<<std::endl;
@@ -114,8 +114,8 @@ TouziEdgeDetector<TInputImage,TOutputImage>
 }
 
 template <class TInputImage, class TOutputImage>
-const typename TouziEdgeDetector<TInputImage,TOutputImage>::OutputImageType *
-TouziEdgeDetector<TInputImage,TOutputImage>
+const typename TouziEdgeDetectorImageFilter<TInputImage,TOutputImage>::OutputImageType *
+TouziEdgeDetectorImageFilter<TInputImage,TOutputImage>
 ::GetOutputDirection()
 {
 	this->Update();
@@ -124,7 +124,7 @@ TouziEdgeDetector<TInputImage,TOutputImage>
 
 
 template< class TInputImage, class TOutputImage>
-void TouziEdgeDetector< TInputImage, TOutputImage>
+void TouziEdgeDetectorImageFilter< TInputImage, TOutputImage>
 ::ThreadedGenerateData(	
 			const 	OutputImageRegionType& 		outputRegionForThread,
                        	int 	threadId
@@ -329,7 +329,7 @@ std::cout<< cpt << std::endl;
  */
 template <class TInputImage, class TOutput>
 void 
-TouziEdgeDetector<TInputImage, TOutput>::PrintSelf(std::ostream& os, itk::Indent indent) const
+TouziEdgeDetectorImageFilter<TInputImage, TOutput>::PrintSelf(std::ostream& os, itk::Indent indent) const
 {
   Superclass::PrintSelf( os, indent );
   os << indent << "Radius: " << m_Radius << std::endl;
diff --git a/Code/FeatureExtraction/otbTouziEdgeDetector.h b/Code/FeatureExtraction/otbTouziEdgeDetector.h
index f1ec47a11e..3eb1fa08d6 100755
--- a/Code/FeatureExtraction/otbTouziEdgeDetector.h
+++ b/Code/FeatureExtraction/otbTouziEdgeDetector.h
@@ -8,8 +8,8 @@
   $Id$ 
 
 =========================================================================*/
-#ifndef __otbTouziEdgeDetector_h
-#define __otbTouziEdgeDetector_h
+#ifndef __otbTouziEdgeDetectorImageFilter_h
+#define __otbTouziEdgeDetectorImageFilter_h
 
 #include "itkImageToImageFilter.h"
 #include "itkImage.h"
@@ -22,7 +22,7 @@
 namespace otb
 {
 
-/** \class TouziEdgeDetector
+/** \class TouziEdgeDetectorImageFilter
  * \brief Application of a filter of detection of contours.
  *
  * This class implements the Touzi's ratio edge detector used to detect 
@@ -50,7 +50,7 @@ namespace otb
  */
 
 template <class TInputImage, class TOutputImage>
-class  ITK_EXPORT TouziEdgeDetector :  public itk::ImageToImageFilter< TInputImage, TOutputImage >
+class  ITK_EXPORT TouziEdgeDetectorImageFilter :  public itk::ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
   /** 	Extrait les dimensions aussi bien des images 
@@ -67,7 +67,7 @@ public:
   typedef TOutputImage OutputImageType;
 
   /** "typedef" pour les classes standards. */
-  typedef TouziEdgeDetector Self;
+  typedef TouziEdgeDetectorImageFilter Self;
   typedef itk::ImageToImageFilter< InputImageType, OutputImageType> Superclass;
   typedef itk::SmartPointer<Self> Pointer;
   typedef itk::SmartPointer<const Self>  ConstPointer;
@@ -76,7 +76,7 @@ public:
   itkNewMacro(Self);
 
   /** Retourne le nom de la classe. */
-  itkTypeMacro(TouziEdgeDetector, itk::ImageToImageFilter);
+  itkTypeMacro(TouziEdgeDetectorImageFilter, itk::ImageToImageFilter);
   
   /** Définition des images supportées. */
   typedef typename InputImageType::PixelType InputPixelType;
@@ -96,7 +96,7 @@ public:
   itkGetConstReferenceMacro(Radius, SizeType);
  
 
   /** TouziEdgeDetector a besoin d'une zone de traitement plus large en entrée qu'en sortie 
    * afin de permettre une utilisation du filtre par la méthode dite pipeline
    *
    * \sa ImageToImageFilter::GenerateInputRequestedRegion() */
@@ -105,13 +105,13 @@ public:
   const OutputImageType * GetOutputDirection();
   
 protected:
-  TouziEdgeDetector();
-  virtual ~TouziEdgeDetector() {};
+  TouziEdgeDetectorImageFilter();
+  virtual ~TouziEdgeDetectorImageFilter() {};
   void PrintSelf(std::ostream& os, itk::Indent indent) const;
 
   void BeforeThreadedGenerateData();
 
   /** TouziEdgeDetector peut etre implémentée pour un traitement de filtre multithreaded.
    * Ainsi, cette implémentation fournit la méthode ThreadedGenerateData()
    * qui est appelée pour chaque thread du process. Les données image sont allouées automatiquement 
    * par la classe "mère" en appelant la méthode ThreadedGenerateData(). ThreadedGenerateData peut seulement 
@@ -123,7 +123,7 @@ protected:
                             int threadId );
 
 private:
-  TouziEdgeDetector(const Self&); //purposely not implemented
+  TouziEdgeDetectorImageFilter(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 
   /** Déclaration du rayon */
@@ -136,7 +136,7 @@ private:
 } // end namespace otb
 
 #ifndef OTB_MANUAL_INSTANTIATION
-#include "otbTouziEdgeDetector.txx"
+#include "otbTouziEdgeDetectorImageFilter.txx"
 #endif
 
   
@@ -96,7 +96,7 @@ public:
  
 
-  /** TouziEdgeDetector a besoin d'une zone de traitement plus large en entrée qu'en sortie 
+  /** TouziEdgeDetectorImageFilter a besoin d'une zone de traitement plus large en entrée qu'en sortie 
    * afin de permettre une utilisation du filtre par la méthode dite pipeline
    *
@@ -105,13 +105,13 @@ public:
   void BeforeThreadedGenerateData();
 
-  /** TouziEdgeDetector peut etre implémentée pour un traitement de filtre multithreaded.
+  /** TouziEdgeDetectorImageFilter peut etre implémentée pour un traitement de filtre multithreaded.
    * Ainsi, cette implémentation fournit la méthode ThreadedGenerateData()
    * qui est appelée pour chaque thread du process. Les données image sont allouées automatiquement 
-- 
GitLab